==> cego-2.18.7.tar.gz: cego-2.18.7/src/CegoProcCursorCloseStmt.cc <==
///////////////////////////////////////////////////////////////////////////////
//                                                         
// CegoProcCursorCloseStmt.cc  
// --------------------------                                                     
// Cego procedure cursor close statement implementation
//                                                         
// Design and Implementation by Bjoern Lemke               
//                                                         
// (C)opyright 2000-2010 Bjoern Lemke                        
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; see the file COPYING.  If not, write to
// the Free Software Foundation, 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.
//
// IMPLEMENTATION MODULE
//
// Class: CegoProcCursorCloseStmt
// 
// Description:
//
// Status: QG-2.6
//
///////////////////////////////////////////////////////////////////////////////

// base includes
#include <lfcbase/Exception.h>

// cego includes
#include "CegoSelect.h"
#include "CegoProcCursorCloseStmt.h"

CegoProcCursorCloseStmt::CegoProcCursorCloseStmt(CegoProcCursor *pCur,CegoProcBlock *pBlock) : CegoProcStmt(pBlock)
{
    _pCur = pCur;
}

CegoProcCursorCloseStmt::~CegoProcCursorCloseStmt()  
{
}

CegoException CegoProcCursorCloseStmt::execute()
{
    if ( _pCur )
    {
	_pCur->close();
    }
    return NONE_EXCEP;
}

Chain CegoProcCursorCloseStmt::toChain(const Chain& indent) const
{
    Chain s;

    s += indent + Chain("close ");
    s += _pCur->getName();
    return s;
}

==> cego-2.31.5.tar.gz: cego-2.31.5/src/CegoProcCursorCloseStmt.cc <==
///////////////////////////////////////////////////////////////////////////////
//                                                         
// CegoProcCursorCloseStmt.cc  
// --------------------------                                                     
// Cego procedure cursor close statement implementation
//                                                         
// Design and Implementation by Bjoern Lemke               
//                                                         
// (C)opyright 2000-2016 Bjoern Lemke
//
// IMPLEMENTATION MODULE
//
// Class: CegoProcCursorCloseStmt
//
// Description: Stored procedure statement for cursor closing
//
// Status: CLEAN
//
///////////////////////////////////////////////////////////////////////////////

// LFC INCLUDES
#include <lfcbase/Exception.h>
// CEGO INCLUDES
#include "CegoSelect.h"
#include "CegoProcCursorCloseStmt.h"
#include "CegoDatabaseFormater.h"

CegoProcCursorCloseStmt::CegoProcCursorCloseStmt(CegoProcCursor *pCur,CegoProcBlock *pBlock) : CegoProcStmt(pBlock)
{
    _pCur = pCur;
}

CegoProcCursorCloseStmt::~CegoProcCursorCloseStmt()  
{
}

CegoException CegoProcCursorCloseStmt::execute()
{
    if ( _pCur )
    {
	_pCur->close();
    }
    return NONE_EXCEP;
}

Chain CegoProcCursorCloseStmt::toChain(const Chain& indent) const
{
    Chain s;

    s += indent + Chain("close ");
    s += _pCur->getName();
    return s;
}

Chain CegoProcCursorCloseStmt::dbFormat(CegoDatabaseFormater *pForm) const
{
    return pForm->formatProcCursorCloseStmt(_pCur->getName());
}
